pub fn parse_ndjson<T: DeserializeOwned>(raw: &str) -> Vec<T>Expand description
Parse NDJSON, skipping blank lines and a trailing partial line (a writer may be mid-append when we read).
pub fn parse_ndjson<T: DeserializeOwned>(raw: &str) -> Vec<T>Parse NDJSON, skipping blank lines and a trailing partial line (a writer may be mid-append when we read).