resolve_artifacts

Function resolve_artifacts 

pub fn resolve_artifacts(
    value: &Value,
    bundle_dir: &Path,
    max_bytes: u64,
) -> Value
Resolve $artifact references in a value by inlining artifact file contents (up to max_bytes per artifact) from the bundle directory. References that escape the bundle directory or exceed the limit are replaced by placeholders.