Reconnecting WebSocket client for remote mode (piw --connect ws://…).
The background task treats subscriptions and artifact requests as desired
state, so reconnects cannot replay stale commands.
Reconnecting WebSocket client for remote mode (piw --connect ws://…).
The background task treats subscriptions and artifact requests as desired
state, so reconnects cannot replay stale commands.