pub fn layout_graph(snapshot: &DefinitionSnapshot) -> GraphLayoutExpand description
Build ranks with virtual pass-through cells so every forward edge connects adjacent ranks, then order cells within ranks by neighbor barycenter.
pub fn layout_graph(snapshot: &DefinitionSnapshot) -> GraphLayoutBuild ranks with virtual pass-through cells so every forward edge connects adjacent ranks, then order cells within ranks by neighbor barycenter.