Strict version-1 client envelopes shared by local and remote piw transports.
Structs
Enums
- Page
Kind - PatchOp
- RFC 6902 ops we use, plus
append(add a batch of items to an array). - Server
Message
Constants
Functions
- apply_
patch - Apply a patch to a view document in place. Returns an error message on the first op that does not apply (the caller should resnapshot).
- canonical_
json - encode_
request - parse_
client_ request - parse_
server_ message