pub fn apply_patch(target: &mut Value, patch: &[PatchOp]) -> Result<(), String>
Apply a patch to a view document in place. Returns an error message on the first op that does not apply (the caller should resnapshot).