render_graph_with_layout

Function render_graph_with_layout 

pub fn render_graph_with_layout(
    view: &GraphView<'_>,
    layout: &GraphLayout,
    selected_step_index: i64,
    at_latest_step: bool,
    now_ms: i64,
    node_style: GraphNodeStyle,
) -> Option<RenderedGraph>
Render against a retained language-neutral scene. Workflow definitions are immutable, so ranks and routes can be shared by local and remote clients and reused across status-only revisions.