Module protocol

Module protocol 

Strict version-1 client envelopes shared by local and remote piw transports.

Structs

ClientRequest
ServerEvent
ServerHello
ServerResponse
TargetPatch

Enums

PageKind
PatchOp
RFC 6902 ops we use, plus append (add a batch of items to an array).
ServerMessage

Constants

PROTOCOL_ID

Functions

apply_patch
Apply a patch to a view document in place. Returns an error message on the first op that does not apply (the caller should resnapshot).
canonical_json
encode_request
parse_client_request
parse_server_message