Wire types for the live replay protocol (pi-workflows.replay.v1), plus
the JSON Patch subset (with the append extension op) used for view
synchronization. See docs/live-replay-protocol.md.
Structs
Enums
- Client
Message - Page
Kind - PatchOp
- RFC 6902 ops we use, plus
append(add a batch of items to an array). - Server
Message
Constants
Functions
- apply_
patch - Apply a patch to a view document in place. Returns an error message on the first op that does not apply (the caller should resnapshot).