pub struct RunData<'a> {Show 35 fields
pub graph_revision: u64,
pub state: &'a RunState,
pub graph_steps: &'a [StepRecord],
pub taken_transitions: &'a [String],
pub graph_cursor: u64,
pub step_start: u64,
pub step_total: u64,
pub snapshot: Option<&'a DefinitionSnapshot>,
pub graph_layout: Option<&'a GraphLayout>,
pub events: &'a [Value],
pub trace_start: u64,
pub trace_total: u64,
pub session_bound: bool,
pub session_entries: &'a [Value],
pub session_entry_start: u64,
pub session_entry_total: u64,
pub session_events: &'a [Value],
pub session_event_start: u64,
pub session_event_total: u64,
pub session_events_malformed: bool,
pub session_events_torn_tail: bool,
pub session_capture: Option<&'a Value>,
pub session_replay_checkpoint: Option<&'a Value>,
pub settings_scopes: &'a [Value],
pub settings_start: u64,
pub settings_total: u64,
pub follow_up_queue: Option<&'a Value>,
pub follow_up_start: u64,
pub follow_up_total: u64,
pub update_start: u64,
pub update_total: u64,
pub live: bool,
pub possibly_interrupted: bool,
pub run_dir: Option<&'a Path>,
pub remote_artifacts: HashMap<String, Result<String, String>>,
}Expand description
Borrowed view of one run, identical for local and remote providers.
Fields
graph_revision: u64state: &'a RunStategraph_steps: &'a [StepRecord]taken_transitions: &'a [String]graph_cursor: u64step_start: u64step_total: u64snapshot: Option<&'a DefinitionSnapshot>graph_layout: Option<&'a GraphLayout>events: &'a [Value]trace_start: u64trace_total: u64session_bound: boolsession_entries: &'a [Value]session_entry_start: u64session_entry_total: u64session_events: &'a [Value]session_event_start: u64session_event_total: u64session_events_malformed: boolsession_events_torn_tail: boolsession_capture: Option<&'a Value>session_replay_checkpoint: Option<&'a Value>settings_scopes: &'a [Value]settings_start: u64settings_total: u64follow_up_queue: Option<&'a Value>follow_up_start: u64follow_up_total: u64update_start: u64update_total: u64live: boolpossibly_interrupted: boolrun_dir: Option<&'a Path>Bundle directory when reading the filesystem directly; lets previews inline small artifacts instead of showing placeholders.
remote_artifacts: HashMap<String, Result<String, String>>Auto Trait Implementations
impl<'a> Freeze for RunData<'a>
impl<'a> RefUnwindSafe for RunData<'a>
impl<'a> Send for RunData<'a>
impl<'a> Sync for RunData<'a>
impl<'a> Unpin for RunData<'a>
impl<'a> UnsafeUnpin for RunData<'a>
impl<'a> UnwindSafe for RunData<'a>